@@ -1,4 +1,4 @@
-#$Id: Wortschatz.pm,v 1.9 2005/11/21 13:58:07 manonegra Exp $
+#$Id: Wortschatz.pm 1057 2008-02-28 17:54:09Z schroeer $
 
 package Lingua::DE::Wortschatz;
 
@@ -11,7 +11,7 @@ use Exporter 'import';
 our @EXPORT_OK = qw(use_service help);
 our %EXPORT_TAGS = (all => [@EXPORT_OK]);
  
-our $VERSION = sprintf("1.2%d%03d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+our $VERSION = "1.25";
 
 my $BASE_URL = 'http://anonymous:anonymous@pcai055.informatik.uni-leipzig.de:8100/axis/services/';
 my $LIMIT    = 10;
@@ -25,15 +25,18 @@ my %services=( # service_name => [ 'corpus', [ 'inparam<=default>', .. ], [ 'out
     Sentences       => [ 'de', ['Wort',"Limit=$LIMIT"], ['Satz'] ],
     RightNeighbours => [ 'de', ['Wort',"Limit=$LIMIT"], ['Wort','Nachbar','Signifikanz'] ],
     LeftNeighbours  => [ 'de', ['Wort',"Limit=$LIMIT"], ['Nachbar','Wort','Signifikanz'] ],
-    Frequencies     => [ 'de', ['Wort',"Limit=$LIMIT"], ['Anzahl','Frequenzklasse'] ],
+    Frequencies     => [ 'de', ['Wort'], ['Anzahl','Frequenzklasse'] ],
     Synonyms        => [ 'de', ['Wort',"Limit=$LIMIT"], ['Synonym'] ],
     Thesaurus       => [ 'de', ['Wort',"Limit=$LIMIT"], ['Synonym'] ],
-    Wordforms       => [ 'de', ['Word',"Limit=$LIMIT"], ['Form'] ], #find their nice trap
+    Wordforms       => [ 'de', ['Word',"Limit=$LIMIT"], ['Form'] ], #find the trap that wortschatz.u-l guys have hidden here
     Similarity      => [ 'de', ['Wort',"Limit=$LIMIT"], ['Wort','Verwandter','Signifikanz'] ],
     LeftCollocationFinder
                     => [ 'de', ['Wort','Wortart',"Limit=$LIMIT"], ['Kollokation','Wortart','Wort'] ],
     RightCollocationFinder
                     => [ 'de', ['Wort','Wortart',"Limit=$LIMIT"], ['Wort','Kollokation','Wortart'] ],
+    Sachgebiet      => [ 'de', ['Wort'], ['Sachgebiet'] ],
+    Kreuzwortraetsel
+                    => [ 'de', ['Wort','Wortlaenge',"Limit=$LIMIT"], ['Wort'] ],
 );
 
 sub use_service {
@@ -104,7 +107,7 @@ sub cmd {
 package Lingua::DE::Wortschatz::Result;
 use strict;
 
-our $VERSION = sprintf("1.2%d%03d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+our $VERSION = "1.24";
 
 sub new {
     my ($proto,$service,@names) = @_;
@@ -161,8 +164,11 @@ Lingua::DE::Wortschatz - wortschatz.uni-leipzig.de webservice client
 =head1 SYNOPSIS
 
     use Lingua::DE::Wortschatz;
+    # use Lingua::DE::Wortschatz ':all'; # import all functions
     
     my $result=Lingua::DE::Wortschatz::use_service('T','toll');
+    # my $result=use_service('T','toll'); # with imported functions
+    
     $result->dump;
     
     @lines=$result->hashrefs();
@@ -172,6 +178,8 @@ Lingua::DE::Wortschatz - wortschatz.uni-leipzig.de webservice client
 
     print Lingua::DE::Wortschatz::help('T');
     print Lingua::DE::Wortschatz::help('full');
+    
+    $result->dump;
 
 =head1 DESCRIPTION
 
@@ -184,8 +192,15 @@ The webservices at L<http://wortschatz.uni-leipzig.de> provide
 access to a database of the german word pool. Available
 services include tools to reduce words to base form, find synonyms,
 significant neighbours, example sentences and more. All public
-services at L<http://wortschatz.uni-leipzig.de> are available.
-See below for a detailed list.
+services at L<http://wortschatz.uni-leipzig.de> are available
+through this client. See the detailed list below.
+
+I have nothing to do with the University of Leipzig and the Wortschatz
+project. Personally, I'm just an average german native speaker and can only guess
+on questions related to the german language. Further answers to frequent questions
+are that this program will really run on Windows, provided that Perl is installed.
+The program will indeed allow to perform automated queries with perl scripts.
+It can be used from the command line, too. There is no GUI.
 
 =head1 FUNCTIONS
 
@@ -215,11 +230,15 @@ Service names can be abbreviated to the shortest unique form.
   * Similarity Wort Limit=10
   * LeftCollocationFinder Wort Wortart Limit=10
   * RightCollocationFinder Wort Wortart Limit=10
+  * Sachgebiet Wort  
+  * Kreuzwortraetsel Wort Wortlaenge Limit=10
 
 A full list of available services, their parameters
 and additional information on what each service does
 can be obtained with the help function.
 
+For the Kreuzwortraetsel service, use % as a placeholder in parameter Wort.
+
 =head2 help(?$service)
 
 Returns a string containing information about the service
@@ -294,9 +313,9 @@ but it's short and it works. But see it as a hack.
 
 =head1 AUTHOR/COPYRIGHT
 
-This is C<$Id: Wortschatz.pm,v 1.9 2005/11/21 13:58:07 manonegra Exp $>.
+This is C<$Id: Wortschatz.pm 1057 2008-02-28 17:54:09Z schroeer $>.
 
-Copyright 2005 Daniel Schrer (L<daniel@daimla1.de>).
+Copyright 2005 - 2008 Daniel Schrer (L<schroeer@cpan.org>).
 
 This program is free software;
 you can redistribute it and/or modify it under the same terms as Perl itself.
